@@ -275,10 +275,10 @@ class Sequential():
             if epoch+1 == epochs:
                 if self.val_inputs is not None and self.val_targets is not None:
                     line_length = (len("train_loss: ") + len(str(np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5))) + len(" · val_loss: ") + len(str(np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5))) + len(" | train_accuracy: ") + len(str(np.around(self.accuracy(self.train_targets,self.train_outputs),5))) + len(" · val_accuracy: ") + len(str(np.around(self.accuracy(self.val_targets,self.val_outputs),5))))
-                    print("" + line_length * "-" + f"\ntrain_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} | val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}\n" + line_length * "-")
+                    print("\n" + line_length * "-" + f"\ntrain_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} · train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)} | val_loss: {np.around(self.val_cost_fn.loss(self.val_targets, self.val_outputs),5)} · val_accuracy: {np.around(self.accuracy(self.val_targets,self.val_outputs),5)}\n" + line_length * "-")
                 else:
                     line_length = (len("train_loss: ") + len(str(np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5))) + len(" | train_accuracy: ") + len(str(np.around(self.accuracy(self.train_targets,self.train_outputs),5))))
-                    print("" + line_length * "-" + f"\ntrain_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} | train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)}\n" + line_length * "-")
+                    print("\n" + line_length * "-" + f"\ntrain_loss: {np.around(self.train_cost_fn.loss(self.train_targets, self.train_outputs),5)} | train_accuracy: {np.around(self.accuracy(self.train_targets,self.train_outputs),5)}\n" + line_length * "-")
         elif verbose == 0:
             return 
         else:
